from django.test import TestCase

# from colorfield.widgets import ColorWidget


class ColorWidgetTestCase(TestCase):
    def setUp(self):
        pass

    def tearDown(self):
        pass
